==> redwood-lazylayout-compose-jvm-0.5.0-sources.jar: commonMain/app/cash/redwood/lazylayout/compose/LazyList.kt <==
package app.cash.redwood.lazylayout.compose

import androidx.compose.runtime.Composable
import app.cash.redwood.Modifier
import app.cash.redwood.RedwoodCodegenApi
import app.cash.redwood.compose.RedwoodComposeNode
import app.cash.redwood.compose.WidgetNode
import app.cash.redwood.layout.api.Constraint
import app.cash.redwood.layout.api.CrossAxisAlignment
import app.cash.redwood.lazylayout.widget.LazyList
import app.cash.redwood.lazylayout.widget.RedwoodLazyLayoutWidgetFactoryProvider
import app.cash.redwood.ui.Margin
import kotlin.Boolean
import kotlin.Int
import kotlin.OptIn
import kotlin.Unit

@Composable
@OptIn(RedwoodCodegenApi::class)
public fun LazyList(
  isVertical: Boolean,
  onViewportChanged: (Int, Int) -> Unit,
  itemsBefore: Int,
  itemsAfter: Int,
  width: Constraint,
  height: Constraint,
  margin: Margin,
  crossAxisAlignment: CrossAxisAlignment,
  modifier: Modifier = Modifier,
  placeholder: @Composable () -> Unit,
  items: @Composable () -> Unit,
) {
  RedwoodComposeNode<RedwoodLazyLayoutWidgetFactoryProvider<*>, LazyList<*>>(
      factory = { it.RedwoodLazyLayout.LazyList() },
      update = {
        set(modifier, WidgetNode.SetModifiers)
        set(isVertical) { recordChanged(); widget.isVertical(it) }
        set(onViewportChanged) { recordChanged(); widget.onViewportChanged(it) }
        set(itemsBefore) { recordChanged(); widget.itemsBefore(it) }
        set(itemsAfter) { recordChanged(); widget.itemsAfter(it) }
        set(width) { recordChanged(); widget.width(it) }
        set(height) { recordChanged(); widget.height(it) }
        set(margin) { recordChanged(); widget.margin(it) }
        set(crossAxisAlignment) { recordChanged(); widget.crossAxisAlignment(it) }
      },
      content = {
        into(LazyList<*>::placeholder) {
          placeholder()
        }
        into(LazyList<*>::items) {
          items()
        }
      },
      )
}

==> redwood-lazylayout-compose-jvm-0.8.0-sources.jar: commonMain/app/cash/redwood/lazylayout/compose/LazyList.kt <==
@file:Suppress("DEPRECATION", "OVERRIDE_DEPRECATION")

package app.cash.redwood.lazylayout.compose

import androidx.compose.runtime.Composable
import app.cash.redwood.Modifier
import app.cash.redwood.RedwoodCodegenApi
import app.cash.redwood.compose.RedwoodComposeNode
import app.cash.redwood.compose.WidgetNode
import app.cash.redwood.layout.api.Constraint
import app.cash.redwood.layout.api.CrossAxisAlignment
import app.cash.redwood.lazylayout.api.ScrollItemIndex
import app.cash.redwood.lazylayout.widget.LazyList
import app.cash.redwood.lazylayout.widget.RedwoodLazyLayoutWidgetFactoryProvider
import app.cash.redwood.ui.Margin
import kotlin.Boolean
import kotlin.Int
import kotlin.OptIn
import kotlin.Suppress
import kotlin.Unit

@Composable
@OptIn(RedwoodCodegenApi::class)
public fun LazyList(
  isVertical: Boolean,
  onViewportChanged: (Int, Int) -> Unit,
  itemsBefore: Int,
  itemsAfter: Int,
  width: Constraint,
  height: Constraint,
  margin: Margin,
  crossAxisAlignment: CrossAxisAlignment,
  scrollItemIndex: ScrollItemIndex,
  modifier: Modifier = Modifier,
  placeholder: @Composable () -> Unit,
  items: @Composable () -> Unit,
) {
  RedwoodComposeNode<RedwoodLazyLayoutWidgetFactoryProvider<*>, LazyList<*>>(
      factory = { it.RedwoodLazyLayout.LazyList() },
      update = {
        set(modifier, WidgetNode.SetModifiers)
        set(isVertical) { recordChanged(); widget.isVertical(it) }
        set(onViewportChanged) { recordChanged(); widget.onViewportChanged(it) }
        set(itemsBefore) { recordChanged(); widget.itemsBefore(it) }
        set(itemsAfter) { recordChanged(); widget.itemsAfter(it) }
        set(width) { recordChanged(); widget.width(it) }
        set(height) { recordChanged(); widget.height(it) }
        set(margin) { recordChanged(); widget.margin(it) }
        set(crossAxisAlignment) { recordChanged(); widget.crossAxisAlignment(it) }
        set(scrollItemIndex) { recordChanged(); widget.scrollItemIndex(it) }
      },
      content = {
        into(LazyList<*>::placeholder) {
          placeholder()
        }
        into(LazyList<*>::items) {
          items()
        }
      },
      )
}
